# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: App.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Definitions_pb2 as Definitions__pb2
import PdmObject_pb2 as PdmObject__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='App.proto',
  package='rips',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\tApp.proto\x12\x04rips\x1a\x11\x44\x65\x66initions.proto\x1a\x0fPdmObject.proto\"N\n\x07Version\x12\x15\n\rmajor_version\x18\x01 \x01(\x05\x12\x15\n\rminor_version\x18\x02 \x01(\x05\x12\x15\n\rpatch_version\x18\x03 \x01(\x05\":\n\x0bRuntimeInfo\x12+\n\x08\x61pp_type\x18\x01 \x01(\x0e\x32\x19.rips.ApplicationTypeEnum*C\n\x13\x41pplicationTypeEnum\x12\x13\n\x0fGUI_APPLICATION\x10\x00\x12\x17\n\x13\x43ONSOLE_APPLICATION\x10\x01\x32\xb9\x01\n\x03\x41pp\x12*\n\nGetVersion\x12\x0b.rips.Empty\x1a\r.rips.Version\"\x00\x12\"\n\x04\x45xit\x12\x0b.rips.Empty\x1a\x0b.rips.Empty\"\x00\x12\x32\n\x0eGetRuntimeInfo\x12\x0b.rips.Empty\x1a\x11.rips.RuntimeInfo\"\x00\x12.\n\x0cGetPdmObject\x12\x0b.rips.Empty\x1a\x0f.rips.PdmObject\"\x00\x62\x06proto3'
  ,
  dependencies=[Definitions__pb2.DESCRIPTOR,PdmObject__pb2.DESCRIPTOR,])

_APPLICATIONTYPEENUM = _descriptor.EnumDescriptor(
  name='ApplicationTypeEnum',
  full_name='rips.ApplicationTypeEnum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GUI_APPLICATION', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONSOLE_APPLICATION', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=195,
  serialized_end=262,
)
_sym_db.RegisterEnumDescriptor(_APPLICATIONTYPEENUM)

ApplicationTypeEnum = enum_type_wrapper.EnumTypeWrapper(_APPLICATIONTYPEENUM)
GUI_APPLICATION = 0
CONSOLE_APPLICATION = 1



_VERSION = _descriptor.Descriptor(
  name='Version',
  full_name='rips.Version',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='major_version', full_name='rips.Version.major_version', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minor_version', full_name='rips.Version.minor_version', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='patch_version', full_name='rips.Version.patch_version', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=133,
)


_RUNTIMEINFO = _descriptor.Descriptor(
  name='RuntimeInfo',
  full_name='rips.RuntimeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_type', full_name='rips.RuntimeInfo.app_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135,
  serialized_end=193,
)

_RUNTIMEINFO.fields_by_name['app_type'].enum_type = _APPLICATIONTYPEENUM
DESCRIPTOR.message_types_by_name['Version'] = _VERSION
DESCRIPTOR.message_types_by_name['RuntimeInfo'] = _RUNTIMEINFO
DESCRIPTOR.enum_types_by_name['ApplicationTypeEnum'] = _APPLICATIONTYPEENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Version = _reflection.GeneratedProtocolMessageType('Version', (_message.Message,), {
  'DESCRIPTOR' : _VERSION,
  '__module__' : 'App_pb2'
  # @@protoc_insertion_point(class_scope:rips.Version)
  })
_sym_db.RegisterMessage(Version)

RuntimeInfo = _reflection.GeneratedProtocolMessageType('RuntimeInfo', (_message.Message,), {
  'DESCRIPTOR' : _RUNTIMEINFO,
  '__module__' : 'App_pb2'
  # @@protoc_insertion_point(class_scope:rips.RuntimeInfo)
  })
_sym_db.RegisterMessage(RuntimeInfo)



_APP = _descriptor.ServiceDescriptor(
  name='App',
  full_name='rips.App',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=265,
  serialized_end=450,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetVersion',
    full_name='rips.App.GetVersion',
    index=0,
    containing_service=None,
    input_type=Definitions__pb2._EMPTY,
    output_type=_VERSION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Exit',
    full_name='rips.App.Exit',
    index=1,
    containing_service=None,
    input_type=Definitions__pb2._EMPTY,
    output_type=Definitions__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRuntimeInfo',
    full_name='rips.App.GetRuntimeInfo',
    index=2,
    containing_service=None,
    input_type=Definitions__pb2._EMPTY,
    output_type=_RUNTIMEINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPdmObject',
    full_name='rips.App.GetPdmObject',
    index=3,
    containing_service=None,
    input_type=Definitions__pb2._EMPTY,
    output_type=PdmObject__pb2._PDMOBJECT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_APP)

DESCRIPTOR.services_by_name['App'] = _APP

# @@protoc_insertion_point(module_scope)



######################################################################
# This script sets values for SOIL for all grid cells in the first case in the project
######################################################################
import rips

resinsight = rips.Instance.find()

case = resinsight.project.case(case_id=0)
total_cell_count = case.cell_count().reservoir_cell_count

values = []
for i in range(0, total_cell_count):
    values.append(i % 2 * 0.75)

print("Applying values to full grid")
case.set_grid_property(values, "DYNAMIC_NATIVE", "SOIL", 0)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Grid.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Definitions_pb2 as Definitions__pb2
import Case_pb2 as Case__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='Grid.proto',
  package='rips',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\nGrid.proto\x12\x04rips\x1a\x11\x44\x65\x66initions.proto\x1a\nCase.proto\"J\n\x0bGridRequest\x12\'\n\x0c\x63\x61se_request\x18\x01 \x01(\x0b\x32\x11.rips.CaseRequest\x12\x12\n\ngrid_index\x18\x02 \x01(\x05\"1\n\x0eGridDimensions\x12\x1f\n\ndimensions\x18\x01 \x01(\x0b\x32\x0b.rips.Vec3i2\xbf\x01\n\x04Grid\x12:\n\x0eGetCellCenters\x12\x11.rips.GridRequest\x1a\x11.rips.CellCenters\"\x00\x30\x01\x12?\n\x0eGetCellCorners\x12\x11.rips.GridRequest\x1a\x16.rips.CellCornersArray\"\x00\x30\x01\x12:\n\rGetDimensions\x12\x11.rips.GridRequest\x1a\x14.rips.GridDimensions\"\x00\x62\x06proto3'
  ,
  dependencies=[Definitions__pb2.DESCRIPTOR,Case__pb2.DESCRIPTOR,])




_GRIDREQUEST = _descriptor.Descriptor(
  name='GridRequest',
  full_name='rips.GridRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='case_request', full_name='rips.GridRequest.case_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grid_index', full_name='rips.GridRequest.grid_index', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51,
  serialized_end=125,
)


_GRIDDIMENSIONS = _descriptor.Descriptor(
  name='GridDimensions',
  full_name='rips.GridDimensions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dimensions', full_name='rips.GridDimensions.dimensions', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=127,
  serialized_end=176,
)

_GRIDREQUEST.fields_by_name['case_request'].message_type = Case__pb2._CASEREQUEST
_GRIDDIMENSIONS.fields_by_name['dimensions'].message_type = Definitions__pb2._VEC3I
DESCRIPTOR.message_types_by_name['GridRequest'] = _GRIDREQUEST
DESCRIPTOR.message_types_by_name['GridDimensions'] = _GRIDDIMENSIONS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GridRequest = _reflection.GeneratedProtocolMessageType('GridRequest', (_message.Message,), {
  'DESCRIPTOR' : _GRIDREQUEST,
  '__module__' : 'Grid_pb2'
  # @@protoc_insertion_point(class_scope:rips.GridRequest)
  })
_sym_db.RegisterMessage(GridRequest)

GridDimensions = _reflection.GeneratedProtocolMessageType('GridDimensions', (_message.Message,), {
  'DESCRIPTOR' : _GRIDDIMENSIONS,
  '__module__' : 'Grid_pb2'
  # @@protoc_insertion_point(class_scope:rips.GridDimensions)
  })
_sym_db.RegisterMessage(GridDimensions)



_GRID = _descriptor.ServiceDescriptor(
  name='Grid',
  full_name='rips.Grid',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=179,
  serialized_end=370,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetCellCenters',
    full_name='rips.Grid.GetCellCenters',
    index=0,
    containing_service=None,
    input_type=_GRIDREQUEST,
    output_type=Definitions__pb2._CELLCENTERS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCellCorners',
    full_name='rips.Grid.GetCellCorners',
    index=1,
    containing_service=None,
    input_type=_GRIDREQUEST,
    output_type=Definitions__pb2._CELLCORNERSARRAY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDimensions',
    full_name='rips.Grid.GetDimensions',
    index=2,
    containing_service=None,
    input_type=_GRIDREQUEST,
    output_type=_GRIDDIMENSIONS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_GRID)

DESCRIPTOR.services_by_name['Grid'] = _GRID

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Properties.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Definitions_pb2 as Definitions__pb2
import Case_pb2 as Case__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='Properties.proto',
  package='rips',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10Properties.proto\x12\x04rips\x1a\x11\x44\x65\x66initions.proto\x1a\nCase.proto\"\xa1\x01\n\x1a\x41vailablePropertiesRequest\x12\'\n\x0c\x63\x61se_request\x18\x01 \x01(\x0b\x32\x11.rips.CaseRequest\x12)\n\rproperty_type\x18\x02 \x01(\x0e\x32\x12.rips.PropertyType\x12/\n\x0eporosity_model\x18\x03 \x01(\x0e\x32\x17.rips.PorosityModelType\"-\n\x13\x41vailableProperties\x12\x16\n\x0eproperty_names\x18\x01 \x03(\t\"\xd4\x01\n\x0fPropertyRequest\x12\'\n\x0c\x63\x61se_request\x18\x01 \x01(\x0b\x32\x11.rips.CaseRequest\x12)\n\rproperty_type\x18\x02 \x01(\x0e\x32\x12.rips.PropertyType\x12\x15\n\rproperty_name\x18\x03 \x01(\t\x12\x11\n\ttime_step\x18\x04 \x01(\x05\x12\x12\n\ngrid_index\x18\x05 \x01(\x05\x12/\n\x0eporosity_model\x18\x06 \x01(\x0e\x32\x17.rips.PorosityModelType\"\x19\n\x08TimeStep\x12\r\n\x05index\x18\x01 \x01(\x05\"q\n\x12PropertyInputChunk\x12\'\n\x06params\x18\x01 \x01(\x0b\x32\x15.rips.PropertyRequestH\x00\x12%\n\x06values\x18\x02 \x01(\x0b\x32\x13.rips.PropertyChunkH\x00\x42\x0b\n\tChunkType\"\x1f\n\rPropertyChunk\x12\x0e\n\x06values\x18\x01 \x03(\x01*\xc7\x01\n\x0cPropertyType\x12\x12\n\x0e\x44YNAMIC_NATIVE\x10\x00\x12\x11\n\rSTATIC_NATIVE\x10\x01\x12\r\n\tSOURSIMRL\x10\x02\x12\r\n\tGENERATED\x10\x03\x12\x12\n\x0eINPUT_PROPERTY\x10\x04\x12\x13\n\x0f\x46ORMATION_NAMES\x10\x05\x12\x14\n\x10\x46LOW_DIAGNOSTICS\x10\x06\x12\x16\n\x12INJECTION_FLOODING\x10\x07\x12\x0b\n\x07REMOVED\x10\x08\x12\x0e\n\tUNDEFINED\x10\xe7\x07\x32\xe6\x03\n\nProperties\x12W\n\x16GetAvailableProperties\x12 .rips.AvailablePropertiesRequest\x1a\x19.rips.AvailableProperties\"\x00\x12G\n\x15GetActiveCellProperty\x12\x15.rips.PropertyRequest\x1a\x13.rips.PropertyChunk\"\x00\x30\x01\x12I\n\x17GetSelectedCellProperty\x12\x15.rips.PropertyRequest\x1a\x13.rips.PropertyChunk\"\x00\x30\x01\x12\x41\n\x0fGetGridProperty\x12\x15.rips.PropertyRequest\x1a\x13.rips.PropertyChunk\"\x00\x30\x01\x12V\n\x15SetActiveCellProperty\x12\x18.rips.PropertyInputChunk\x1a\x1f.rips.ClientToServerStreamReply\"\x00(\x01\x12P\n\x0fSetGridProperty\x12\x18.rips.PropertyInputChunk\x1a\x1f.rips.ClientToServerStreamReply\"\x00(\x01\x62\x06proto3'
  ,
  dependencies=[Definitions__pb2.DESCRIPTOR,Case__pb2.DESCRIPTOR,])

_PROPERTYTYPE = _descriptor.EnumDescriptor(
  name='PropertyType',
  full_name='rips.PropertyType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DYNAMIC_NATIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATIC_NATIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOURSIMRL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GENERATED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INPUT_PROPERTY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FORMATION_NAMES', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLOW_DIAGNOSTICS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INJECTION_FLOODING', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REMOVED', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNDEFINED', index=9, number=999,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=659,
  serialized_end=858,
)
_sym_db.RegisterEnumDescriptor(_PROPERTYTYPE)

PropertyType = enum_type_wrapper.EnumTypeWrapper(_PROPERTYTYPE)
DYNAMIC_NATIVE = 0
STATIC_NATIVE = 1
SOURSIMRL = 2
GENERATED = 3
INPUT_PROPERTY = 4
FORMATION_NAMES = 5
FLOW_DIAGNOSTICS = 6
INJECTION_FLOODING = 7
REMOVED = 8
UNDEFINED = 999



_AVAILABLEPROPERTIESREQUEST = _descriptor.Descriptor(
  name='AvailablePropertiesRequest',
  full_name='rips.AvailablePropertiesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='case_request', full_name='rips.AvailablePropertiesRequest.case_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='property_type', full_name='rips.AvailablePropertiesRequest.property_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='porosity_model', full_name='rips.AvailablePropertiesRequest.porosity_model', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=219,
)


_AVAILABLEPROPERTIES = _descriptor.Descriptor(
  name='AvailableProperties',
  full_name='rips.AvailableProperties',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='property_names', full_name='rips.AvailableProperties.property_names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=266,
)


_PROPERTYREQUEST = _descriptor.Descriptor(
  name='PropertyRequest',
  full_name='rips.PropertyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='case_request', full_name='rips.PropertyRequest.case_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='property_type', full_name='rips.PropertyRequest.property_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='property_name', full_name='rips.PropertyRequest.property_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_step', full_name='rips.PropertyRequest.time_step', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grid_index', full_name='rips.PropertyRequest.grid_index', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='porosity_model', full_name='rips.PropertyRequest.porosity_model', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=269,
  serialized_end=481,
)


_TIMESTEP = _descriptor.Descriptor(
  name='TimeStep',
  full_name='rips.TimeStep',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='rips.TimeStep.index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=483,
  serialized_end=508,
)


_PROPERTYINPUTCHUNK = _descriptor.Descriptor(
  name='PropertyInputChunk',
  full_name='rips.PropertyInputChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='rips.PropertyInputChunk.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='rips.PropertyInputChunk.values', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='ChunkType', full_name='rips.PropertyInputChunk.ChunkType',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=510,
  serialized_end=623,
)


_PROPERTYCHUNK = _descriptor.Descriptor(
  name='PropertyChunk',
  full_name='rips.PropertyChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='rips.PropertyChunk.values', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=625,
  serialized_end=656,
)

_AVAILABLEPROPERTIESREQUEST.fields_by_name['case_request'].message_type = Case__pb2._CASEREQUEST
_AVAILABLEPROPERTIESREQUEST.fields_by_name['property_type'].enum_type = _PROPERTYTYPE
_AVAILABLEPROPERTIESREQUEST.fields_by_name['porosity_model'].enum_type = Case__pb2._POROSITYMODELTYPE
_PROPERTYREQUEST.fields_by_name['case_request'].message_type = Case__pb2._CASEREQUEST
_PROPERTYREQUEST.fields_by_name['property_type'].enum_type = _PROPERTYTYPE
_PROPERTYREQUEST.fields_by_name['porosity_model'].enum_type = Case__pb2._POROSITYMODELTYPE
_PROPERTYINPUTCHUNK.fields_by_name['params'].message_type = _PROPERTYREQUEST
_PROPERTYINPUTCHUNK.fields_by_name['values'].message_type = _PROPERTYCHUNK
_PROPERTYINPUTCHUNK.oneofs_by_name['ChunkType'].fields.append(
  _PROPERTYINPUTCHUNK.fields_by_name['params'])
_PROPERTYINPUTCHUNK.fields_by_name['params'].containing_oneof = _PROPERTYINPUTCHUNK.oneofs_by_name['ChunkType']
_PROPERTYINPUTCHUNK.oneofs_by_name['ChunkType'].fields.append(
  _PROPERTYINPUTCHUNK.fields_by_name['values'])
_PROPERTYINPUTCHUNK.fields_by_name['values'].containing_oneof = _PROPERTYINPUTCHUNK.oneofs_by_name['ChunkType']
DESCRIPTOR.message_types_by_name['AvailablePropertiesRequest'] = _AVAILABLEPROPERTIESREQUEST
DESCRIPTOR.message_types_by_name['AvailableProperties'] = _AVAILABLEPROPERTIES
DESCRIPTOR.message_types_by_name['PropertyRequest'] = _PROPERTYREQUEST
DESCRIPTOR.message_types_by_name['TimeStep'] = _TIMESTEP
DESCRIPTOR.message_types_by_name['PropertyInputChunk'] = _PROPERTYINPUTCHUNK
DESCRIPTOR.message_types_by_name['PropertyChunk'] = _PROPERTYCHUNK
DESCRIPTOR.enum_types_by_name['PropertyType'] = _PROPERTYTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AvailablePropertiesRequest = _reflection.GeneratedProtocolMessageType('AvailablePropertiesRequest', (_message.Message,), {
  'DESCRIPTOR' : _AVAILABLEPROPERTIESREQUEST,
  '__module__' : 'Properties_pb2'
  # @@protoc_insertion_point(class_scope:rips.AvailablePropertiesRequest)
  })
_sym_db.RegisterMessage(AvailablePropertiesRequest)

AvailableProperties = _reflection.GeneratedProtocolMessageType('AvailableProperties', (_message.Message,), {
  'DESCRIPTOR' : _AVAILABLEPROPERTIES,
  '__module__' : 'Properties_pb2'
  # @@protoc_insertion_point(class_scope:rips.AvailableProperties)
  })
_sym_db.RegisterMessage(AvailableProperties)

PropertyRequest = _reflection.GeneratedProtocolMessageType('PropertyRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROPERTYREQUEST,
  '__module__' : 'Properties_pb2'
  # @@protoc_insertion_point(class_scope:rips.PropertyRequest)
  })
_sym_db.RegisterMessage(PropertyRequest)

TimeStep = _reflection.GeneratedProtocolMessageType('TimeStep', (_message.Message,), {
  'DESCRIPTOR' : _TIMESTEP,
  '__module__' : 'Properties_pb2'
  # @@protoc_insertion_point(class_scope:rips.TimeStep)
  })
_sym_db.RegisterMessage(TimeStep)

PropertyInputChunk = _reflection.GeneratedProtocolMessageType('PropertyInputChunk', (_message.Message,), {
  'DESCRIPTOR' : _PROPERTYINPUTCHUNK,
  '__module__' : 'Properties_pb2'
  # @@protoc_insertion_point(class_scope:rips.PropertyInputChunk)
  })
_sym_db.RegisterMessage(PropertyInputChunk)

PropertyChunk = _reflection.GeneratedProtocolMessageType('PropertyChunk', (_message.Message,), {
  'DESCRIPTOR' : _PROPERTYCHUNK,
  '__module__' : 'Properties_pb2'
  # @@protoc_insertion_point(class_scope:rips.PropertyChunk)
  })
_sym_db.RegisterMessage(PropertyChunk)



_PROPERTIES = _descriptor.ServiceDescriptor(
  name='Properties',
  full_name='rips.Properties',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=861,
  serialized_end=1347,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetAvailableProperties',
    full_name='rips.Properties.GetAvailableProperties',
    index=0,
    containing_service=None,
    input_type=_AVAILABLEPROPERTIESREQUEST,
    output_type=_AVAILABLEPROPERTIES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetActiveCellProperty',
    full_name='rips.Properties.GetActiveCellProperty',
    index=1,
    containing_service=None,
    input_type=_PROPERTYREQUEST,
    output_type=_PROPERTYCHUNK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSelectedCellProperty',
    full_name='rips.Properties.GetSelectedCellProperty',
    index=2,
    containing_service=None,
    input_type=_PROPERTYREQUEST,
    output_type=_PROPERTYCHUNK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetGridProperty',
    full_name='rips.Properties.GetGridProperty',
    index=3,
    containing_service=None,
    input_type=_PROPERTYREQUEST,
    output_type=_PROPERTYCHUNK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetActiveCellProperty',
    full_name='rips.Properties.SetActiveCellProperty',
    index=4,
    containing_service=None,
    input_type=_PROPERTYINPUTCHUNK,
    output_type=Definitions__pb2._CLIENTTOSERVERSTREAMREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetGridProperty',
    full_name='rips.Properties.SetGridProperty',
    index=5,
    containing_service=None,
    input_type=_PROPERTYINPUTCHUNK,
    output_type=Definitions__pb2._CLIENTTOSERVERSTREAMREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PROPERTIES)

DESCRIPTOR.services_by_name['Properties'] = _PROPERTIES

# @@protoc_insertion_point(module_scope)



import sys
import os

sys.path.insert(1, os.path.join(sys.path[0], "../../"))
import rips

import dataroot


def test_10k(rips_instance, initialize_test):
    case_root_path = dataroot.PATH + "/TEST10K_FLT_LGR_NNC"
    case_path = case_root_path + "/TEST10K_FLT_LGR_NNC.EGRID"
    case = rips_instance.project.load_case(path=case_path)
    assert len(case.grids()) == 2
    well_path_files = [
        case_root_path + "/wellpath_a.dev",
        case_root_path + "/wellpath_b.dev",
    ]
    well_path_names = rips_instance.project.import_well_paths(well_path_files)
    wells = rips_instance.project.well_paths()
    assert len(wells) == 2
    assert wells[0].name == "Well Path A"
    assert wells[1].name == "Well Path B"



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Case.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import PdmObject_pb2 as PdmObject__pb2
import Definitions_pb2 as Definitions__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='Case.proto',
  package='rips',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\nCase.proto\x12\x04rips\x1a\x0fPdmObject.proto\x1a\x11\x44\x65\x66initions.proto\"\x19\n\x0b\x43\x61seRequest\x12\n\n\x02id\x18\x01 \x01(\x05\"D\n\x08\x43\x61seInfo\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x10\n\x08group_id\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\"-\n\rCaseInfoArray\x12\x1c\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x0e.rips.CaseInfo\"g\n\x0b\x42oundingBox\x12\r\n\x05min_x\x18\x01 \x01(\x01\x12\r\n\x05max_x\x18\x02 \x01(\x01\x12\r\n\x05min_y\x18\x03 \x01(\x01\x12\r\n\x05max_y\x18\x04 \x01(\x01\x12\r\n\x05min_z\x18\x05 \x01(\x01\x12\r\n\x05max_z\x18\x06 \x01(\x01\"%\n\tCaseGroup\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\"2\n\nCaseGroups\x12$\n\x0b\x63\x61se_groups\x18\x01 \x03(\x0b\x32\x0f.rips.CaseGroup\"\x1a\n\tGridCount\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\"D\n\tCellCount\x12\x19\n\x11\x61\x63tive_cell_count\x18\x01 \x01(\x05\x12\x1c\n\x14reservoir_cell_count\x18\x02 \x01(\x05\"k\n\x0f\x43\x65llInfoRequest\x12\'\n\x0c\x63\x61se_request\x18\x01 \x01(\x0b\x32\x11.rips.CaseRequest\x12/\n\x0eporosity_model\x18\x02 \x01(\x0e\x32\x17.rips.PorosityModelType\"-\n\rCellInfoArray\x12\x1c\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x0e.rips.CellInfo\"\x98\x01\n\x08\x43\x65llInfo\x12\x12\n\ngrid_index\x18\x01 \x01(\x05\x12\x19\n\x11parent_grid_index\x18\x02 \x01(\x05\x12\x1c\n\x14\x63oarsening_box_index\x18\x03 \x01(\x05\x12\x1e\n\tlocal_ijk\x18\x04 \x01(\x0b\x32\x0b.rips.Vec3i\x12\x1f\n\nparent_ijk\x18\x05 \x01(\x0b\x32\x0b.rips.Vec3i\"9\n\x13\x43oarseningInfoArray\x12\"\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x14.rips.CoarseningInfo\"D\n\x0e\x43oarseningInfo\x12\x18\n\x03min\x18\x01 \x01(\x0b\x32\x0b.rips.Vec3i\x12\x18\n\x03max\x18\x02 \x01(\x0b\x32\x0b.rips.Vec3i\"2\n\rTimeStepDates\x12!\n\x05\x64\x61tes\x18\x01 \x03(\x0b\x32\x12.rips.TimeStepDate\"f\n\x0cTimeStepDate\x12\x0c\n\x04year\x18\x01 \x01(\x05\x12\r\n\x05month\x18\x02 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\x05\x12\x0c\n\x04hour\x18\x04 \x01(\x05\x12\x0e\n\x06minute\x18\x05 \x01(\x05\x12\x0e\n\x06second\x18\x06 \x01(\x05\"&\n\x0e\x44\x61ysSinceStart\x12\x14\n\x0c\x64\x61y_decimals\x18\x01 \x03(\x01\"<\n\x0cSelectedCell\x12\x12\n\ngrid_index\x18\x01 \x01(\x05\x12\x18\n\x03ijk\x18\x02 \x01(\x0b\x32\x0b.rips.Vec3i\"2\n\rSelectedCells\x12!\n\x05\x63\x65lls\x18\x01 \x03(\x0b\x32\x12.rips.SelectedCell*9\n\x11PorosityModelType\x12\x10\n\x0cMATRIX_MODEL\x10\x00\x12\x12\n\x0e\x46RACTURE_MODEL\x10\x01\x32\x94\x06\n\x04\x43\x61se\x12\x34\n\x0cGetGridCount\x12\x11.rips.CaseRequest\x1a\x0f.rips.GridCount\"\x00\x12\x38\n\x0cGetCellCount\x12\x15.rips.CellInfoRequest\x1a\x0f.rips.CellCount\"\x00\x12K\n\x19GetCellInfoForActiveCells\x12\x15.rips.CellInfoRequest\x1a\x13.rips.CellInfoArray\"\x00\x30\x01\x12K\n\x1bGetCellCenterForActiveCells\x12\x15.rips.CellInfoRequest\x1a\x11.rips.CellCenters\"\x00\x30\x01\x12Q\n\x1cGetCellCornersForActiveCells\x12\x15.rips.CellInfoRequest\x1a\x16.rips.CellCornersArray\"\x00\x30\x01\x12H\n\x16GetCoarseningInfoArray\x12\x11.rips.CaseRequest\x1a\x19.rips.CoarseningInfoArray\"\x00\x12\x38\n\x0cGetTimeSteps\x12\x11.rips.CaseRequest\x1a\x13.rips.TimeStepDates\"\x00\x12>\n\x10GetSelectedCells\x12\x11.rips.CaseRequest\x1a\x13.rips.SelectedCells\"\x00\x30\x01\x12>\n\x11GetDaysSinceStart\x12\x11.rips.CaseRequest\x1a\x14.rips.DaysSinceStart\"\x00\x12\x32\n\x0bGetCaseInfo\x12\x11.rips.CaseRequest\x1a\x0e.rips.CaseInfo\"\x00\x12\x34\n\x0cGetPdmObject\x12\x11.rips.CaseRequest\x1a\x0f.rips.PdmObject\"\x00\x12\x41\n\x17GetReservoirBoundingBox\x12\x11.rips.CaseRequest\x1a\x11.rips.BoundingBox\"\x00\x62\x06proto3'
  ,
  dependencies=[PdmObject__pb2.DESCRIPTOR,Definitions__pb2.DESCRIPTOR,])

_POROSITYMODELTYPE = _descriptor.EnumDescriptor(
  name='PorosityModelType',
  full_name='rips.PorosityModelType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MATRIX_MODEL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FRACTURE_MODEL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1244,
  serialized_end=1301,
)
_sym_db.RegisterEnumDescriptor(_POROSITYMODELTYPE)

PorosityModelType = enum_type_wrapper.EnumTypeWrapper(_POROSITYMODELTYPE)
MATRIX_MODEL = 0
FRACTURE_MODEL = 1



_CASEREQUEST = _descriptor.Descriptor(
  name='CaseRequest',
  full_name='rips.CaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='rips.CaseRequest.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=81,
)


_CASEINFO = _descriptor.Descriptor(
  name='CaseInfo',
  full_name='rips.CaseInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='rips.CaseInfo.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_id', full_name='rips.CaseInfo.group_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='rips.CaseInfo.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='rips.CaseInfo.type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=151,
)


_CASEINFOARRAY = _descriptor.Descriptor(
  name='CaseInfoArray',
  full_name='rips.CaseInfoArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='rips.CaseInfoArray.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=153,
  serialized_end=198,
)


_BOUNDINGBOX = _descriptor.Descriptor(
  name='BoundingBox',
  full_name='rips.BoundingBox',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_x', full_name='rips.BoundingBox.min_x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_x', full_name='rips.BoundingBox.max_x', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_y', full_name='rips.BoundingBox.min_y', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_y', full_name='rips.BoundingBox.max_y', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_z', full_name='rips.BoundingBox.min_z', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_z', full_name='rips.BoundingBox.max_z', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=200,
  serialized_end=303,
)


_CASEGROUP = _descriptor.Descriptor(
  name='CaseGroup',
  full_name='rips.CaseGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='rips.CaseGroup.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='rips.CaseGroup.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=342,
)


_CASEGROUPS = _descriptor.Descriptor(
  name='CaseGroups',
  full_name='rips.CaseGroups',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='case_groups', full_name='rips.CaseGroups.case_groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=344,
  serialized_end=394,
)


_GRIDCOUNT = _descriptor.Descriptor(
  name='GridCount',
  full_name='rips.GridCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='rips.GridCount.count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=396,
  serialized_end=422,
)


_CELLCOUNT = _descriptor.Descriptor(
  name='CellCount',
  full_name='rips.CellCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='active_cell_count', full_name='rips.CellCount.active_cell_count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reservoir_cell_count', full_name='rips.CellCount.reservoir_cell_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=424,
  serialized_end=492,
)


_CELLINFOREQUEST = _descriptor.Descriptor(
  name='CellInfoRequest',
  full_name='rips.CellInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='case_request', full_name='rips.CellInfoRequest.case_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='porosity_model', full_name='rips.CellInfoRequest.porosity_model', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=494,
  serialized_end=601,
)


_CELLINFOARRAY = _descriptor.Descriptor(
  name='CellInfoArray',
  full_name='rips.CellInfoArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='rips.CellInfoArray.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=603,
  serialized_end=648,
)


_CELLINFO = _descriptor.Descriptor(
  name='CellInfo',
  full_name='rips.CellInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='grid_index', full_name='rips.CellInfo.grid_index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_grid_index', full_name='rips.CellInfo.parent_grid_index', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='coarsening_box_index', full_name='rips.CellInfo.coarsening_box_index', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_ijk', full_name='rips.CellInfo.local_ijk', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_ijk', full_name='rips.CellInfo.parent_ijk', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=651,
  serialized_end=803,
)


_COARSENINGINFOARRAY = _descriptor.Descriptor(
  name='CoarseningInfoArray',
  full_name='rips.CoarseningInfoArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='rips.CoarseningInfoArray.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=805,
  serialized_end=862,
)


_COARSENINGINFO = _descriptor.Descriptor(
  name='CoarseningInfo',
  full_name='rips.CoarseningInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min', full_name='rips.CoarseningInfo.min', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='rips.CoarseningInfo.max', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=864,
  serialized_end=932,
)


_TIMESTEPDATES = _descriptor.Descriptor(
  name='TimeStepDates',
  full_name='rips.TimeStepDates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dates', full_name='rips.TimeStepDates.dates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=934,
  serialized_end=984,
)


_TIMESTEPDATE = _descriptor.Descriptor(
  name='TimeStepDate',
  full_name='rips.TimeStepDate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='year', full_name='rips.TimeStepDate.year', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month', full_name='rips.TimeStepDate.month', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='day', full_name='rips.TimeStepDate.day', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hour', full_name='rips.TimeStepDate.hour', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minute', full_name='rips.TimeStepDate.minute', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='second', full_name='rips.TimeStepDate.second', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=986,
  serialized_end=1088,
)


_DAYSSINCESTART = _descriptor.Descriptor(
  name='DaysSinceStart',
  full_name='rips.DaysSinceStart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='day_decimals', full_name='rips.DaysSinceStart.day_decimals', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1090,
  serialized_end=1128,
)


_SELECTEDCELL = _descriptor.Descriptor(
  name='SelectedCell',
  full_name='rips.SelectedCell',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='grid_index', full_name='rips.SelectedCell.grid_index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ijk', full_name='rips.SelectedCell.ijk', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1130,
  serialized_end=1190,
)


_SELECTEDCELLS = _descriptor.Descriptor(
  name='SelectedCells',
  full_name='rips.SelectedCells',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cells', full_name='rips.SelectedCells.cells', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1192,
  serialized_end=1242,
)

_CASEINFOARRAY.fields_by_name['data'].message_type = _CASEINFO
_CASEGROUPS.fields_by_name['case_groups'].message_type = _CASEGROUP
_CELLINFOREQUEST.fields_by_name['case_request'].message_type = _CASEREQUEST
_CELLINFOREQUEST.fields_by_name['porosity_model'].enum_type = _POROSITYMODELTYPE
_CELLINFOARRAY.fields_by_name['data'].message_type = _CELLINFO
_CELLINFO.fields_by_name['local_ijk'].message_type = Definitions__pb2._VEC3I
_CELLINFO.fields_by_name['parent_ijk'].message_type = Definitions__pb2._VEC3I
_COARSENINGINFOARRAY.fields_by_name['data'].message_type = _COARSENINGINFO
_COARSENINGINFO.fields_by_name['min'].message_type = Definitions__pb2._VEC3I
_COARSENINGINFO.fields_by_name['max'].message_type = Definitions__pb2._VEC3I
_TIMESTEPDATES.fields_by_name['dates'].message_type = _TIMESTEPDATE
_SELECTEDCELL.fields_by_name['ijk'].message_type = Definitions__pb2._VEC3I
_SELECTEDCELLS.fields_by_name['cells'].message_type = _SELECTEDCELL
DESCRIPTOR.message_types_by_name['CaseRequest'] = _CASEREQUEST
DESCRIPTOR.message_types_by_name['CaseInfo'] = _CASEINFO
DESCRIPTOR.message_types_by_name['CaseInfoArray'] = _CASEINFOARRAY
DESCRIPTOR.message_types_by_name['BoundingBox'] = _BOUNDINGBOX
DESCRIPTOR.message_types_by_name['CaseGroup'] = _CASEGROUP
DESCRIPTOR.message_types_by_name['CaseGroups'] = _CASEGROUPS
DESCRIPTOR.message_types_by_name['GridCount'] = _GRIDCOUNT
DESCRIPTOR.message_types_by_name['CellCount'] = _CELLCOUNT
DESCRIPTOR.message_types_by_name['CellInfoRequest'] = _CELLINFOREQUEST
DESCRIPTOR.message_types_by_name['CellInfoArray'] = _CELLINFOARRAY
DESCRIPTOR.message_types_by_name['CellInfo'] = _CELLINFO
DESCRIPTOR.message_types_by_name['CoarseningInfoArray'] = _COARSENINGINFOARRAY
DESCRIPTOR.message_types_by_name['CoarseningInfo'] = _COARSENINGINFO
DESCRIPTOR.message_types_by_name['TimeStepDates'] = _TIMESTEPDATES
DESCRIPTOR.message_types_by_name['TimeStepDate'] = _TIMESTEPDATE
DESCRIPTOR.message_types_by_name['DaysSinceStart'] = _DAYSSINCESTART
DESCRIPTOR.message_types_by_name['SelectedCell'] = _SELECTEDCELL
DESCRIPTOR.message_types_by_name['SelectedCells'] = _SELECTEDCELLS
DESCRIPTOR.enum_types_by_name['PorosityModelType'] = _POROSITYMODELTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CaseRequest = _reflection.GeneratedProtocolMessageType('CaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _CASEREQUEST,
  '__module__' : 'Case_pb2'
  # @@protoc_insertion_point(class_scope:rips.CaseRequest)
  })
_sym_db.RegisterMessage(CaseRequest)

CaseInfo = _reflection.GeneratedProtocolMessageType('CaseInfo', (_message.Message,), {
  'DESCRIPTOR' : _CASEINFO,
  '__module__' : 'Case_pb2'
  # @@protoc_insertion_point(class_scope:rips.CaseInfo)
  })
_sym_db.RegisterMessage(CaseInfo)

CaseInfoArray = _reflection.GeneratedProtocolMessageType('CaseInfoArray', (_message.Message,), {
  'DESCRIPTOR' : _CASEINFOARRAY,
  '__module__' : 'Case_pb2'
  # @@protoc_insertion_point(class_scope:rips.CaseInfoArray)
  })
_sym_db.RegisterMessage(CaseInfoArray)

BoundingBox = _reflection.GeneratedProtocolMessageType('BoundingBox', (_message.Message,), {
  'DESCRIPTOR' : _BOUNDINGBOX,
  '__module__' : 'Case_pb2'
  # @@protoc_insertion_point(class_scope:rips.BoundingBox)
  })
_sym_db.RegisterMessage(BoundingBox)

CaseGroup = _reflection.GeneratedProtocolMessageType('CaseGroup', (_message.Message,), {
  'DESCRIPTOR' : _CASEGROUP,
  '__module__' : 'Case_pb2'
  # @@protoc_insertion_point(class_scope:rips.CaseGroup)
  })
_sym_db.RegisterMessage(CaseGroup)

CaseGroups = _reflection.GeneratedProtocolMessageType('CaseGroups', (_message.Message,), {
  'DESCRIPTOR' : _CASEGROUPS,
  '__module__' : 'Case_pb2'
  # @@protoc_insertion_point(class_scope:rips.CaseGroups)
  })
_sym_db.RegisterMessage(CaseGroups)

GridCount = _reflection.GeneratedProtocolMessageType('GridCount', (_message.Message,), {
  'DESCRIPTOR' : _GRIDCOUNT,
  '__module__' : 'Case_pb2'
  # @@protoc_insertion_point(class_scope:rips.GridCount)
  })
_sym_db.RegisterMessage(GridCount)

CellCount = _reflection.GeneratedProtocolMessageType('CellCount', (_message.Message,), {
  'DESCRIPTOR' : _CELLCOUNT,
  '__module__' : 'Case_pb2'
  # @@protoc_insertion_point(class_scope:rips.CellCount)
  })
_sym_db.RegisterMessage(CellCount)

CellInfoRequest = _reflection.GeneratedProtocolMessageType('CellInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _CELLINFOREQUEST,
  '__module__' : 'Case_pb2'
  # @@protoc_insertion_point(class_scope:rips.CellInfoRequest)
  })
_sym_db.RegisterMessage(CellInfoRequest)

CellInfoArray = _reflection.GeneratedProtocolMessageType('CellInfoArray', (_message.Message,), {
  'DESCRIPTOR' : _CELLINFOARRAY,
  '__module__' : 'Case_pb2'
  # @@protoc_insertion_point(class_scope:rips.CellInfoArray)
  })
_sym_db.RegisterMessage(CellInfoArray)

CellInfo = _reflection.GeneratedProtocolMessageType('CellInfo', (_message.Message,), {
  'DESCRIPTOR' : _CELLINFO,
  '__module__' : 'Case_pb2'
  # @@protoc_insertion_point(class_scope:rips.CellInfo)
  })
_sym_db.RegisterMessage(CellInfo)

CoarseningInfoArray = _reflection.GeneratedProtocolMessageType('CoarseningInfoArray', (_message.Message,), {
  'DESCRIPTOR' : _COARSENINGINFOARRAY,
  '__module__' : 'Case_pb2'
  # @@protoc_insertion_point(class_scope:rips.CoarseningInfoArray)
  })
_sym_db.RegisterMessage(CoarseningInfoArray)

CoarseningInfo = _reflection.GeneratedProtocolMessageType('CoarseningInfo', (_message.Message,), {
  'DESCRIPTOR' : _COARSENINGINFO,
  '__module__' : 'Case_pb2'
  # @@protoc_insertion_point(class_scope:rips.CoarseningInfo)
  })
_sym_db.RegisterMessage(CoarseningInfo)

TimeStepDates = _reflection.GeneratedProtocolMessageType('TimeStepDates', (_message.Message,), {
  'DESCRIPTOR' : _TIMESTEPDATES,
  '__module__' : 'Case_pb2'
  # @@protoc_insertion_point(class_scope:rips.TimeStepDates)
  })
_sym_db.RegisterMessage(TimeStepDates)

TimeStepDate = _reflection.GeneratedProtocolMessageType('TimeStepDate', (_message.Message,), {
  'DESCRIPTOR' : _TIMESTEPDATE,
  '__module__' : 'Case_pb2'
  # @@protoc_insertion_point(class_scope:rips.TimeStepDate)
  })
_sym_db.RegisterMessage(TimeStepDate)

DaysSinceStart = _reflection.GeneratedProtocolMessageType('DaysSinceStart', (_message.Message,), {
  'DESCRIPTOR' : _DAYSSINCESTART,
  '__module__' : 'Case_pb2'
  # @@protoc_insertion_point(class_scope:rips.DaysSinceStart)
  })
_sym_db.RegisterMessage(DaysSinceStart)

SelectedCell = _reflection.GeneratedProtocolMessageType('SelectedCell', (_message.Message,), {
  'DESCRIPTOR' : _SELECTEDCELL,
  '__module__' : 'Case_pb2'
  # @@protoc_insertion_point(class_scope:rips.SelectedCell)
  })
_sym_db.RegisterMessage(SelectedCell)

SelectedCells = _reflection.GeneratedProtocolMessageType('SelectedCells', (_message.Message,), {
  'DESCRIPTOR' : _SELECTEDCELLS,
  '__module__' : 'Case_pb2'
  # @@protoc_insertion_point(class_scope:rips.SelectedCells)
  })
_sym_db.RegisterMessage(SelectedCells)



_CASE = _descriptor.ServiceDescriptor(
  name='Case',
  full_name='rips.Case',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1304,
  serialized_end=2092,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetGridCount',
    full_name='rips.Case.GetGridCount',
    index=0,
    containing_service=None,
    input_type=_CASEREQUEST,
    output_type=_GRIDCOUNT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCellCount',
    full_name='rips.Case.GetCellCount',
    index=1,
    containing_service=None,
    input_type=_CELLINFOREQUEST,
    output_type=_CELLCOUNT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCellInfoForActiveCells',
    full_name='rips.Case.GetCellInfoForActiveCells',
    index=2,
    containing_service=None,
    input_type=_CELLINFOREQUEST,
    output_type=_CELLINFOARRAY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCellCenterForActiveCells',
    full_name='rips.Case.GetCellCenterForActiveCells',
    index=3,
    containing_service=None,
    input_type=_CELLINFOREQUEST,
    output_type=Definitions__pb2._CELLCENTERS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCellCornersForActiveCells',
    full_name='rips.Case.GetCellCornersForActiveCells',
    index=4,
    containing_service=None,
    input_type=_CELLINFOREQUEST,
    output_type=Definitions__pb2._CELLCORNERSARRAY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCoarseningInfoArray',
    full_name='rips.Case.GetCoarseningInfoArray',
    index=5,
    containing_service=None,
    input_type=_CASEREQUEST,
    output_type=_COARSENINGINFOARRAY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTimeSteps',
    full_name='rips.Case.GetTimeSteps',
    index=6,
    containing_service=None,
    input_type=_CASEREQUEST,
    output_type=_TIMESTEPDATES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSelectedCells',
    full_name='rips.Case.GetSelectedCells',
    index=7,
    containing_service=None,
    input_type=_CASEREQUEST,
    output_type=_SELECTEDCELLS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDaysSinceStart',
    full_name='rips.Case.GetDaysSinceStart',
    index=8,
    containing_service=None,
    input_type=_CASEREQUEST,
    output_type=_DAYSSINCESTART,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCaseInfo',
    full_name='rips.Case.GetCaseInfo',
    index=9,
    containing_service=None,
    input_type=_CASEREQUEST,
    output_type=_CASEINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPdmObject',
    full_name='rips.Case.GetPdmObject',
    index=10,
    containing_service=None,
    input_type=_CASEREQUEST,
    output_type=PdmObject__pb2._PDMOBJECT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetReservoirBoundingBox',
    full_name='rips.Case.GetReservoirBoundingBox',
    index=11,
    containing_service=None,
    input_type=_CASEREQUEST,
    output_type=_BOUNDINGBOX,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CASE)

DESCRIPTOR.services_by_name['Case'] = _CASE

# @@protoc_insertion_point(module_scope)



import sys
import os
import math

sys.path.insert(1, os.path.join(sys.path[0], "../../"))
import rips

import dataroot


def check_corner(actual, expected):
    assert math.isclose(actual.x, expected[0], abs_tol=0.1)
    assert math.isclose(actual.y, expected[1], abs_tol=0.1)
    assert math.isclose(actual.z, expected[2], abs_tol=0.1)


def test_10k(rips_instance, initialize_test):
    casePath = dataroot.PATH + "/TEST10K_FLT_LGR_NNC/TEST10K_FLT_LGR_NNC.EGRID"
    case = rips_instance.project.load_case(path=casePath)
    assert len(case.grids()) == 2
    grid = case.grid(index=0)
    dimensions = grid.dimensions()
    assert dimensions.i == 90
    assert dimensions.j == 96
    assert dimensions.k == 36

    cell_centers = grid.cell_centers()
    assert len(cell_centers) == (dimensions.i * dimensions.j * dimensions.k)

    # Test a specific cell (results from ResInsight UI)
    cell_index = 168143
    assert math.isclose(3627.17, cell_centers[cell_index].x, abs_tol=0.1)
    assert math.isclose(5209.75, cell_centers[cell_index].y, abs_tol=0.1)
    assert math.isclose(4179.6, cell_centers[cell_index].z, abs_tol=0.1)

    cell_corners = grid.cell_corners()
    assert len(cell_corners) == (dimensions.i * dimensions.j * dimensions.k)

    # Expected values from ResInsight UI
    expected_corners = [
        [3565.22, 5179.02, 4177.18],
        [3655.67, 5145.34, 4176.63],
        [3690.07, 5240.69, 4180.02],
        [3599.87, 5275.16, 4179.32],
        [3564.13, 5178.61, 4179.75],
        [3654.78, 5144.79, 4179.23],
        [3688.99, 5239.88, 4182.7],
        [3598.62, 5274.48, 4181.96],
    ]
    check_corner(cell_corners[cell_index].c0, expected_corners[0])
    check_corner(cell_corners[cell_index].c1, expected_corners[1])
    check_corner(cell_corners[cell_index].c2, expected_corners[2])
    check_corner(cell_corners[cell_index].c3, expected_corners[3])
    check_corner(cell_corners[cell_index].c4, expected_corners[4])
    check_corner(cell_corners[cell_index].c5, expected_corners[5])
    check_corner(cell_corners[cell_index].c6, expected_corners[6])
    check_corner(cell_corners[cell_index].c7, expected_corners[7])



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SimulationWell.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Definitions_pb2 as Definitions__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='SimulationWell.proto',
  package='rips',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14SimulationWell.proto\x12\x04rips\x1a\x11\x44\x65\x66initions.proto\"M\n\x15SimulationWellRequest\x12\x0f\n\x07\x63\x61se_id\x18\x01 \x01(\x05\x12\x11\n\twell_name\x18\x02 \x01(\t\x12\x10\n\x08timestep\x18\x03 \x01(\x05\":\n\x14SimulationWellStatus\x12\x11\n\twell_type\x18\x01 \x01(\t\x12\x0f\n\x07is_open\x18\x02 \x01(\x08\"~\n\x16SimulationWellCellInfo\x12\x18\n\x03ijk\x18\x01 \x01(\x0b\x32\x0b.rips.Vec3i\x12\x12\n\ngrid_index\x18\x02 \x01(\x05\x12\x0f\n\x07is_open\x18\x03 \x01(\x08\x12\x11\n\tbranch_id\x18\x04 \x01(\x05\x12\x12\n\nsegment_id\x18\x05 \x01(\x05\"I\n\x1bSimulationWellCellInfoArray\x12*\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x1c.rips.SimulationWellCellInfo2\xc2\x01\n\x0eSimulationWell\x12T\n\x17GetSimulationWellStatus\x12\x1b.rips.SimulationWellRequest\x1a\x1a.rips.SimulationWellStatus\"\x00\x12Z\n\x16GetSimulationWellCells\x12\x1b.rips.SimulationWellRequest\x1a!.rips.SimulationWellCellInfoArray\"\x00\x62\x06proto3'
  ,
  dependencies=[Definitions__pb2.DESCRIPTOR,])




_SIMULATIONWELLREQUEST = _descriptor.Descriptor(
  name='SimulationWellRequest',
  full_name='rips.SimulationWellRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='case_id', full_name='rips.SimulationWellRequest.case_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='well_name', full_name='rips.SimulationWellRequest.well_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestep', full_name='rips.SimulationWellRequest.timestep', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=126,
)


_SIMULATIONWELLSTATUS = _descriptor.Descriptor(
  name='SimulationWellStatus',
  full_name='rips.SimulationWellStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='well_type', full_name='rips.SimulationWellStatus.well_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_open', full_name='rips.SimulationWellStatus.is_open', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=128,
  serialized_end=186,
)


_SIMULATIONWELLCELLINFO = _descriptor.Descriptor(
  name='SimulationWellCellInfo',
  full_name='rips.SimulationWellCellInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ijk', full_name='rips.SimulationWellCellInfo.ijk', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grid_index', full_name='rips.SimulationWellCellInfo.grid_index', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_open', full_name='rips.SimulationWellCellInfo.is_open', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='branch_id', full_name='rips.SimulationWellCellInfo.branch_id', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='segment_id', full_name='rips.SimulationWellCellInfo.segment_id', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=314,
)


_SIMULATIONWELLCELLINFOARRAY = _descriptor.Descriptor(
  name='SimulationWellCellInfoArray',
  full_name='rips.SimulationWellCellInfoArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='rips.SimulationWellCellInfoArray.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=316,
  serialized_end=389,
)

_SIMULATIONWELLCELLINFO.fields_by_name['ijk'].message_type = Definitions__pb2._VEC3I
_SIMULATIONWELLCELLINFOARRAY.fields_by_name['data'].message_type = _SIMULATIONWELLCELLINFO
DESCRIPTOR.message_types_by_name['SimulationWellRequest'] = _SIMULATIONWELLREQUEST
DESCRIPTOR.message_types_by_name['SimulationWellStatus'] = _SIMULATIONWELLSTATUS
DESCRIPTOR.message_types_by_name['SimulationWellCellInfo'] = _SIMULATIONWELLCELLINFO
DESCRIPTOR.message_types_by_name['SimulationWellCellInfoArray'] = _SIMULATIONWELLCELLINFOARRAY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SimulationWellRequest = _reflection.GeneratedProtocolMessageType('SimulationWellRequest', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATIONWELLREQUEST,
  '__module__' : 'SimulationWell_pb2'
  # @@protoc_insertion_point(class_scope:rips.SimulationWellRequest)
  })
_sym_db.RegisterMessage(SimulationWellRequest)

SimulationWellStatus = _reflection.GeneratedProtocolMessageType('SimulationWellStatus', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATIONWELLSTATUS,
  '__module__' : 'SimulationWell_pb2'
  # @@protoc_insertion_point(class_scope:rips.SimulationWellStatus)
  })
_sym_db.RegisterMessage(SimulationWellStatus)

SimulationWellCellInfo = _reflection.GeneratedProtocolMessageType('SimulationWellCellInfo', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATIONWELLCELLINFO,
  '__module__' : 'SimulationWell_pb2'
  # @@protoc_insertion_point(class_scope:rips.SimulationWellCellInfo)
  })
_sym_db.RegisterMessage(SimulationWellCellInfo)

SimulationWellCellInfoArray = _reflection.GeneratedProtocolMessageType('SimulationWellCellInfoArray', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATIONWELLCELLINFOARRAY,
  '__module__' : 'SimulationWell_pb2'
  # @@protoc_insertion_point(class_scope:rips.SimulationWellCellInfoArray)
  })
_sym_db.RegisterMessage(SimulationWellCellInfoArray)



_SIMULATIONWELL = _descriptor.ServiceDescriptor(
  name='SimulationWell',
  full_name='rips.SimulationWell',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=392,
  serialized_end=586,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetSimulationWellStatus',
    full_name='rips.SimulationWell.GetSimulationWellStatus',
    index=0,
    containing_service=None,
    input_type=_SIMULATIONWELLREQUEST,
    output_type=_SIMULATIONWELLSTATUS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSimulationWellCells',
    full_name='rips.SimulationWell.GetSimulationWellCells',
    index=1,
    containing_service=None,
    input_type=_SIMULATIONWELLREQUEST,
    output_type=_SIMULATIONWELLCELLINFOARRAY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SIMULATIONWELL)

DESCRIPTOR.services_by_name['SimulationWell'] = _SIMULATIONWELL

# @@protoc_insertion_point(module_scope)
